@@ -19,6 +19,10 @@
 
 #include <stdint.h>
 
+uint8_t *bm_init(void);
+int bm_check(uint8_t *bm, uint16_t v);
+void bm_set(uint8_t *bm, uint16_t v);
+
 uint8_t **pbm_init(void);
 int pbm_check(uint8_t **b, uint32_t v);
 void pbm_set(uint8_t **b, uint32_t v);
