@@ -8,10 +8,10 @@
 
 /* send module for performing arbitrary UDP scans */
 
+#include <stdbool.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <stdint.h>
-#include <unistd.h>
 #include <string.h>
 #include <assert.h>
 #include <sys/time.h>
@@ -71,6 +71,8 @@ const unsigned char charset_all[257] = {
     0xfd, 0xfe, 0xff, 0x00};
 
 static int num_ports;
+#define SOURCE_PORT_VALIDATION_MODULE_DEFAULT false; // default to NOT validating source port
+static bool should_validate_src_port = SOURCE_PORT_VALIDATION_MODULE_DEFAULT
 
 probe_module_t module_udp;
 
@@ -144,6 +146,12 @@ int udp_global_initialize(struct state_conf *conf)
 {
 	uint32_t udp_template_max_len = 0;
 	num_ports = conf->source_port_last - conf->source_port_first + 1;
+	should_validate_src_port = SOURCE_PORT_VALIDATION_MODULE_DEFAULT
+	if (conf->validate_source_port_override == VALIDATE_SRC_PORT_ENABLE_OVERRIDE) {
+		log_debug("udp", "enabling source port validation");
+		should_validate_src_port = true;
+	}
+
 
 	if (!conf->probe_args) {
 		log_error(
@@ -436,7 +444,7 @@ int udp_validate_packet(const struct ip *ip_hdr, uint32_t len, uint32_t *src_ip,
 			uint32_t *validation, const struct port_conf *ports)
 {
 	return udp_do_validate_packet(ip_hdr, len, src_ip, validation,
-				      num_ports, NO_SRC_PORT_VALIDATION, ports);
+				      num_ports, should_validate_src_port, ports);
 }
 
 // Do very basic validation that this is an ICMP response to a packet we sent
